@@ -3,7 +3,7 @@
 
 from __future__ import absolute_import, division, print_function
 
-from ged2doc.dumbsvg import *
+from ged2doc.dumbsvg import Doc, Element, Hyperlink, Line, Rect, Text, Tspan
 
 
 def test_001_element_noval():
@@ -18,6 +18,7 @@ def test_001_element_noval():
     elem = Element('elem', [("attr", "avalue"), ("bttr", "bval")])
     assert elem.xml() == '<elem attr="avalue" bttr="bval" />'
 
+
 def test_002_element_val():
     "Test case for Element class"
 
@@ -27,6 +28,7 @@ def test_002_element_val():
     elem = Element('elem', [("attr", "avalue")], value="some text")
     assert elem.xml() == '<elem attr="avalue">\nsome text\n</elem>'
 
+
 def test_003_element_subelem():
     "Test case for Element class"
 
@@ -42,6 +44,7 @@ def test_003_element_subelem():
     elem.add(Element('elem2', value="value2"))
     assert elem.xml() == "<elem>\nvalue\n<elem2>\nvalue2\n</elem2>\n</elem>"
 
+
 def test_010_doc():
     "Test case for Doc class"
 
@@ -51,11 +54,13 @@ def test_010_doc():
     assert doc.xml() == """\
 <?xml version="1.0" standalone="no"?>
 <!DOCTYPE svg PUBLIC "-//W3C//DTD SVG 1.1//EN" "http://www.w3.org/Graphics/SVG/1.1/DTD/svg11.dtd">
-<svg width="100" height="100" version="1.1" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink">
+<svg width="100" height="100" version="1.1" xmlns="http://www.w3.org/2000/svg" \
+xmlns:xlink="http://www.w3.org/1999/xlink">
 <elem />
 <elem2 />
 </svg>"""
 
+
 def test_020_line():
     "Test case for Line class"
 
@@ -65,6 +70,7 @@ def test_020_line():
     elem = Line(0, 10, 90, 100, style="fancy")
     assert elem.xml() == '<line x1="0" y1="10" x2="90" y2="100" style="fancy" />'
 
+
 def test_030_rect():
     "Test case for Rect class"
 
@@ -74,6 +80,7 @@ def test_030_rect():
     elem = Rect(0, 10, 90, 100, style="fancy")
     assert elem.xml() == '<rect x="0" y="10" width="90" height="100" style="fancy" />'
 
+
 def test_040_text():
     "Test case for Text class"
 
@@ -86,6 +93,7 @@ def test_040_text():
     elem = Text(font_size="10px", text_anchor="middle", style="fancy", class_="fclass")
     assert elem.xml() == '<text font-size="10px" text-anchor="middle" style="fancy" class="fclass" />'
 
+
 def test_050_tspan():
     "Test case for Tspan class"
 
@@ -95,6 +103,7 @@ def test_050_tspan():
     elem = Tspan(x=10, y="20px", value="Some text")
     assert elem.xml() == '<tspan x="10" y="20px">\nSome text\n</tspan>'
 
+
 def test_050_hyperlink():
     "Test case for Hyperlink class"
 
